# pytest-kairos
The `pytest-kairos` enhances pytest with random number generation, reproducibility, and test repetition. It generates random numbers for tests, allows setting a seed for consistent results, and repeats tests multiple times.
